#! /usr/bin/env python2
# VIM declarations
# vim:tw=0:expandtab:autoindent:tabstop=4:shiftwidth=4:filetype=python:

#alphabetical
import os
import sys
import glob

# all of the variables below are substituted by the build system
__VERSION__="1.0.0"

import TestLib

exeName = os.path.realpath(sys.argv[0])
top_srcdir = os.path.join(os.path.dirname(exeName), "..")
top_builddir = os.getcwd()

sys.path.insert(0,top_srcdir)

# runs all modules TestCase() classes in files that match test*.py
if __name__ == "__main__":
    testModulePath="%s/pyunit/" % top_srcdir

    moduleNames = glob.glob( "%s/test*.py" % testModulePath )
    moduleNames = [ m[len(testModulePath):-3] for m in moduleNames ]

    tests = []
    for moduleName in moduleNames:
        if "testAll" in moduleName:
            continue
        module = __import__(moduleName, globals(), locals(), [])
        module.TestCase.top_srcdir=top_srcdir
        module.TestCase.top_builddir=top_builddir
        tests.append(module.TestCase)

    retval = 1
    if tests:
        retval = TestLib.runTests( tests )

    sys.exit( not retval )



# vim:tw=0:expandtab:autoindent:tabstop=4:shiftwidth=4:filetype=python:
"""
Yum plugin to set up repo for hardware-specific repositories.
"""

import os
import sys

from yum.plugins import TYPE_CORE

__VERSION__="unreleased_version"
version=__VERSION__

requires_api_version = '2.1'
plugin_type = TYPE_CORE
runInitHook = 1

def postconfig_hook(conduit):
    conf = conduit.getConf()
    try:
        import libsmbios_c.system_info as sysinfo
        conf.yumvar["dellsysidpluginver"] = version
        conf.yumvar["sys_dev_id"] = "0x%04x" % sysinfo.get_dell_system_id()
        conf.yumvar["sys_ven_id"] = "0x1028"  # hex
        #conf.yumvar["service_tag"] = sysinfo.get_service_tag()
        conf.yumvar["repo_config"] = conduit.confString("main", "repo_config", default="latest")
    except:
        pass

    global runInitHook
    runInitHook = 0
   

def init_hook(conduit):
    """ 
    Plugin initialization hook. Sets up system id variables.

    Note: this should be compatible with any other vendor plugin that sets
    these variables because we only ever set them on Dell systems.
    """

    global runInitHook
    if not runInitHook:
        return

    conf = conduit.getConf()

    sysid=0
    tag = ""
    try:
        import libsmbios_c.system_info as sysinfo
        sysid = sysinfo.get_dell_system_id()
        #tag = sysinfo.get_service_tag()
    except:
        pass

    conf.yumvar["dellsysidpluginver"] = version

    if sysid:
        conf.yumvar["sys_ven_id"] = "0x1028"  # hex
        conf.yumvar["sys_dev_id"] = "0x%04x" % sysid
        #conf.yumvar["service_tag"] = tag
        conf.yumvar["repo_config"] = conduit.confString("main", "repo_config", default="latest")

    repos = conduit.getRepos()
    for repo in repos.findRepos('*'):
        repo.yumvar.update(conf.yumvar)

    # re-process mirrorlist (it isnt varReplaced like baseUrl is)
    for repo in repos.findRepos('*'):
        try:
            # yum 3.0+
            if repo.mirrorlist:
                for (key, value) in conf.yumvar.items():
                    repo.mirrorlist = repo.mirrorlist.replace("$%s" % key, value)
        except AttributeError:
            pass
    
        try:
            # yum 2.4.3
            if repo.mirrorlistfn:
                for (key, value) in conf.yumvar.items():
                    repo.mirrorlistfn = repo.mirrorlistfn.replace("$%s" % key, value)
        except AttributeError:
            pass





#!/usr/bin/python2
# vim:expandtab:autoindent:tabstop=4:shiftwidth=4:filetype=python:
"""
"""

from __future__ import generators

import sys
import TestLib

pagesize = (4096 * 16)

def getTempDir():
    import sys
    return sys.argv[1]

def getTestDir():
    import sys
    return sys.argv[2]

class TestCase(TestLib.TestCase):
    def setUp(self):
        # write some values to a test file that we will use for both cmos and mem tests
        self.testfile = "%s/%s-testmem.dat" % (getTempDir(), self._testMethodName)
        fd = open(self.testfile, "w+")
        for i in xrange(pagesize*4 + 1):
            fd.write("j")
        fd.close()

        import libsmbios_c.memory as m
        self.memObj = m.MemoryAccess(m.MEMORY_GET_NEW | m.MEMORY_UNIT_TEST_MODE, self.testfile)

        import libsmbios_c.cmos as c
        self.cmosObj = c.CmosAccess(c.CMOS_GET_NEW | c.CMOS_UNIT_TEST_MODE, self.testfile)

        # replace first 26 bytes with alphabet
        for i in xrange(26):
            self.memObj.write(chr(ord("a") + i), i)

        # write pages of '0', '1', and '2'
        for i in xrange(3):
            self.memObj.write(chr(ord("0") + i) * pagesize, 26 + (pagesize * i))

        self.memObj.close_hint(1)

    def tearDown(self):
        del(self.cmosObj)
        del(self.memObj)

    def testForLeaks(self):
        # create/destroy lots of objects to see if we leak
        import libsmbios_c.memory as m
        import libsmbios_c.cmos as c
        for i in xrange(1000):
            mObj = m.MemoryAccess(m.MEMORY_GET_NEW | m.MEMORY_UNIT_TEST_MODE, "/dev/null")
            cObj = c.CmosAccess(c.CMOS_GET_NEW | c.CMOS_UNIT_TEST_MODE, "/dev/null")
            del(mObj)
            del(cObj)

    def testMemoryWrite(self):
        # re-write first 26 bytes. starts with a-z, ends with A-z
        for i in xrange(26):
            b = self.memObj.read(i, 1)
            self.assertEquals( b[0], chr(ord("a") + i) )
            self.memObj.write( chr(ord(b[0]) + ord("A") - ord("a")), i)
            c = self.memObj.read(i, 1)
            self.assertEquals( c[0], chr(ord("A") + i) )

    def testMemoryReadMultipage(self):
        buf = self.memObj.read( 26, pagesize *3 )
        for i in xrange(3):
            for j in xrange(pagesize):
                self.assertEquals( buf[ i*pagesize + j ], chr(ord("0")+i) )

    def testMemorySearch(self):
        ret = self.memObj.search("abc", 0, 4096, 1);
        self.assertEquals( 0, ret );

        ret = self.memObj.search("de", 0, 4096, 1);
        self.assertEquals( 3, ret );

        ret = self.memObj.search("00000000", 0, 4096, 1);
        self.assertEquals( 26, ret );

        self.assertRaises(Exception, self.memObj.search, "nonexistent", 0, 4096, 1);

    def testCmosRead(self):
        for i in xrange(26):
            # index/data ports to 0 for unit testing
            b = self.cmosObj.readByte(0, 0, i)
            self.assertEquals( ord('a') + i, b )

    def testCmosWrite(self):
        import libsmbios_c.cmos as c
        import ctypes
        cObj = c._CmosAccess(c.CMOS_GET_NEW | c.CMOS_UNIT_TEST_MODE, self.testfile)

        # a test callback that increments a counter each time it is called
        def _test_cb(cmosObj, do_update, userdata):
            i = ctypes.cast(userdata, ctypes.POINTER(ctypes.c_uint16))
            i[0] = i[0] + 1
            return 1

        int = ctypes.c_uint16(0)
        cObj.registerCallback(_test_cb, ctypes.pointer(int), None)

        for i in xrange(26):
            # index/data ports to 0 for unit testing
            b = cObj.readByte(0, 0, i)
            self.assertEquals( ord('a') + i, b )
            cObj.writeByte( b + ord('A') - ord('a'), 0, 0, i )
            b = cObj.readByte(0, 0, i)
            self.assertEquals( ord('A') + i, b )

        self.assertEquals(int.value, 26)

        # index port 1 (offset 512 + i) should be '0'
        for i in xrange(26):
            c = cObj.readByte(1, 0, i)
            self.assertEquals(c, ord('0'))




if __name__ == "__main__":
    import TestLib
    sys.exit(not TestLib.runTests( [TestCase] ))



#!/usr/bin/python
# vim: et:ai:sw=4:ts=4:filetype=python:nocindent:

import sys


def writeStdHeaders( out ):
    out.write ("""
#ifndef __STD_SMBIOS_XML_H
#define __STD_SMBIOS_XML_H

//
// This is an *AUTOMATICALLY* *GENERATED* file. Do not edit this file
// as your changes will be lost the next time the file is generated
//

""")

def writeStdFooters( out ):
    out.write ("""

#endif /* __STD_SMBIOS_XML_H */

""")

def processFile( input, output ):
    charsPerLine = 16
    output.write( """
const char stdXml[] = { """)
    
    charsWrittenThisLine = charsPerLine
    while 1:
        c = input.read(1)
        if c == "":   # end of file
            break 
        if charsWrittenThisLine == charsPerLine/2:
            output.write("  ")
        if charsWrittenThisLine >= charsPerLine:
            output.write( "\n" )
            output.write( "\t" )
            charsWrittenThisLine = 1
        output.write( "0x%02x, " % ord(c) )
        charsWrittenThisLine = charsWrittenThisLine + 1
        
    output.write( """0x00
};
""")

def main():
    inputXml = None
    outputHeader = None
    inputXml = sys.argv[1]
    if len(sys.argv) > 2:
        outputHeader = sys.argv[2]

    inputFh = open( inputXml, "r" )
    if outputHeader is not None:
        outputFh = open( outputHeader, "w+" )
    else:
        outputFh = sys.stdout

    writeStdHeaders( outputFh )
    processFile( inputFh, outputFh )
    writeStdFooters( outputFh )


if __name__ == "__main__":
    main()



#! /usr/bin/env python
# VIM declarations
# vim:expandtab:autoindent:tabstop=4:shiftwidth=4:filetype=python:

#must be first
from __future__ import division

import re
import sys
import glob
import os

def processFile( filename ):
    pct = 0
    lineCount = 0
    linesOfCode = 0
    statementsExecuted = 0

    fd = file( filename, "r" )
    while 1:
        line = fd.readline()
        if line == "":
            break

        lineCount = lineCount + 1

        p = re.match( "^\s*-:", line )
        if p is not None:
            continue

        p = re.match( "^\s{0,9}\d+:", line )
        if p is not None:
            linesOfCode = linesOfCode + 1
            statementsExecuted = statementsExecuted + 1
            continue

        p = re.match( "^    #####:", line )
        if p is not None:
            linesOfCode = linesOfCode + 1

    if linesOfCode == 0:
        pct = 1
    else:
        pct = statementsExecuted / linesOfCode

    return ( pct, lineCount, linesOfCode, statementsExecuted )


def main():
    totalLines = 0
    totalLoc = 0
    totalExc = 0
    path = os.path.join(sys.argv[1],  "*.gcov")

    fileList = glob.glob( path )
    fileList.sort()

    print " PCT\tLINES\tCODE\tEXEC\tFILENAME"
    for file in fileList:
        (pct, lines, loc, exc) = processFile( file )
        totalLines = totalLines + lines
        totalLoc = totalLoc + loc
        totalExc = totalExc + exc
        file = os.path.basename(file)
        file = file[:-5]
        print "%3.0f%%\t%d\t%d\t%d\t%s" % ( (pct*100), lines, loc, exc, file )

    if totalLoc == 0:
        pct = 1
    else:
        pct = totalExc / totalLoc
    print
    print "%3.0f%%\t%d\t%d\t%d\t%s" % ( (pct*100), totalLines, totalLoc, totalExc, "TOTAL" )

if __name__ == "__main__":
    main()



#!/usr/bin/python
# vim:expandtab:autoindent:tabstop=4:shiftwidth=4:filetype=python:


import sys
import xml.dom.minidom

import HelperXml

def main():
    try:
        doc = xml.dom.minidom.parse( sys.argv[1]  )
        elem = HelperXml.getNodeElement( doc, "STRUCTUREDEFS" )
        for node in elem.childNodes:
            if node.nodeName == "STRUCTURE":
                print node.getAttribute("description").replace(" ", "_"), " = ", 
                print node.getAttribute( "type" ), ","
    except (IOError, KeyError):
        pass


if __name__ == "__main__":
        main()




# purpose of the following is so we can easily run from built source tree if
# topdir == builddir. (ie. doesnt support out of tree builds, set
# LD_LIBRARY_PATH manually for that)
import os
from _vars import *

# import the .so one time rather than in each submodule
import ctypes
try:
    # try explicit path first
    # this lets us run cleanly from build tree
    # or if user uses wierd --prefix for configure
    # doesnt work from build tree if top_builddir != top_srcdir
    libsmbios_c_DLL = ctypes.cdll.LoadLibrary(os.path.join(libdir, LIBSMBIOS_C_SONAME))
except OSError, e:
    # then let it search
    libsmbios_c_DLL = ctypes.cdll.LoadLibrary(LIBSMBIOS_C_SONAME)

# check ctypes bool support. If it doesnt exist, fake it.
if not getattr(ctypes, "c_bool", None):
    ctypes.c_bool = ctypes.c_uint8

# import all our packages.
import cmos
import memory
import smbios
import smi
import system_info
import token

# push gettext vars into namespaces
import gettext
_t = gettext.translation(GETTEXT_PACKAGE, localedir, fallback=True)
for i in (cmos, memory, smbios, smi, system_info, token, _common):
    setattr(i, "_", _t.ugettext)

__VERSION__ = "uninstalled-version"

_all_ = [
    "cmos", "memory", "smbios", "smi", "system_info", "token",
    "GETTEXT_PACKAGE",
    "localedir", "pkgdatadir", "pythondir", "pkgconfdir"
    ]



#!/usr/bin/python2
# vim:expandtab:autoindent:tabstop=4:shiftwidth=4:filetype=python:
"""
"""

from __future__ import generators

import os
import sys
import xml.dom.minidom
import HelperXml
import TestLib

pagesize = (4096 * 16)

class SkipTest(Exception): pass

def getTempDir():
    import sys
    return sys.argv[1]

def getTestDir():
    import sys
    return sys.argv[2]

class TestCase(TestLib.TestCase):
    def checkSkip(self):
        for testElem in HelperXml.iterNodeElement(self.dom, "TESTINPUT", "testsToSkip"):
            if self._testMethodName == HelperXml.getNodeAttribute(testElem, "name"):
                self.skip=1

    def setUp(self):
        self.skip=0
        self.testInput = "%s/testInput.xml" % getTempDir()
        if os.path.exists(self.testInput):
            self.dom = xml.dom.minidom.parse(self.testInput)
            self.checkSkip()
        else:
            self.skip=1

        import libsmbios_c.memory as m
        import libsmbios_c.cmos as c
        import libsmbios_c.smbios as s

        # initialize global singletons
        m.MemoryAccess(m.MEMORY_GET_SINGLETON | m.MEMORY_UNIT_TEST_MODE, "%s/memdump.dat" % getTempDir())
        c.CmosAccess(c.CMOS_GET_SINGLETON | c.CMOS_UNIT_TEST_MODE, "%s/cmos.dat" % getTempDir())
        s.SmbiosTable(s.SMBIOS_GET_SINGLETON | s.SMBIOS_UNIT_TEST_MODE)

        # use private copies for testing
        self.memObj = m.MemoryAccess(m.MEMORY_GET_NEW | m.MEMORY_UNIT_TEST_MODE, "%s/memdump.dat" % getTempDir())
        self.cmosObj = c.CmosAccess(c.CMOS_GET_NEW | c.CMOS_UNIT_TEST_MODE, "%s/cmos.dat" % getTempDir())
        self.tableObj =  s.SmbiosTable(s.SMBIOS_GET_NEW | s.SMBIOS_UNIT_TEST_MODE)

    def tearDown(self):
        del(self.cmosObj)
        del(self.memObj)

    def testVariousAccessors(self):
        try:
            if self.skip: raise SkipTest()
            biosVendorStr = HelperXml.getNodeText( self.dom, "TESTINPUT", "smbios", "biosInformation", "vendor")
            versionStr = HelperXml.getNodeText( self.dom, "TESTINPUT", "smbios", "biosInformation", "version")
            releaseStr = HelperXml.getNodeText( self.dom, "TESTINPUT", "smbios", "biosInformation", "release")

            biosStruct = self.tableObj.getStructureByType(0) # BIOS Table type
            if len(biosVendorStr):
                self.assertEquals( biosVendorStr, biosStruct.getString(4) ) # BIOS VENDOR
            if len(versionStr):
                self.assertEquals( versionStr, biosStruct.getString(5) ) # BIOS VERSION
            if len(releaseStr):
                self.assertEquals( releaseStr, biosStruct.getString(8) ) # RELEASE DATE

            import libsmbios_c.system_info as si
            self.assertEquals( si.get_bios_version(), biosStruct.getString(5) )
        except SkipTest, e:
            print "skip ",

    def testIdByte(self):
        try:
            if self.skip: raise SkipTest()
            expected = int(HelperXml.getNodeText( self.dom, "TESTINPUT", "systemInfo", "idByte"), 0)

            import libsmbios_c.system_info as si
            self.assertEquals( si.get_dell_system_id(), expected )
        except SkipTest, e:
            print "skip ",

    def testServiceTag(self):
        try:
            if self.skip: raise SkipTest()
            expected = HelperXml.getNodeText( self.dom, "TESTINPUT", "systemInfo", "serviceTag")

            import libsmbios_c.system_info as si
            self.assertEquals( si.get_service_tag(), expected )
        except SkipTest, e:
            print "skip ",

if __name__ == "__main__":
    sys.exit(not TestLib.runTests( [TestCase] ))



#!/usr/bin/python
# VIM declarations
# vim:expandtab:autoindent:tabstop=4:shiftwidth=4:filetype=python:

  #############################################################################
  #
  # Copyright (c) 2003 Dell Computer Corporation
  # All Rights Reserved.
  #
  #############################################################################
"""
$Id: HelperXml.py,v 1.1 2004/03/14 06:09:08 michael_e_brown Exp $
"""

__version__ = "$Revision: 1.1 $"
# $Source: /home/cvsroot-hb/cvsroot/libsmbios/build/scripts/HelperXml.py,v $

import types

def getText(nodelist):
    rc = ""
    if nodelist is not None:
        for node in nodelist:
            if node.nodeType == node.TEXT_NODE:
                rc = rc + node.data
    return rc

def getNodeText( node, *args ):
    rc = ""
    node = getNodeElement(node, *args)
    if node is not None:
        rc = getText( node.childNodes )
    return rc

def getNodeElement( node, *args ):
    if len(args) == 0:
        return node

    #print "DEBUG: args(%s)" % repr(args)
    if node is not None:
        for search in node.childNodes:
            if isinstance(args[0], types.StringTypes):
                if search.nodeName == args[0]:
                    candidate = getNodeElement( search, *args[1:] )
                    if candidate is not None:
                        return candidate
            else:
                if search.nodeName == args[0][0]:
                    attrHash = args[0][1]
                    found = 1
                    for (key, value) in attrHash.items():
                        if search.getAttribute( key ) != value:
                            found = 0
                    if found:
                        candidate = getNodeElement( search, *args[1:] )
                        if candidate is not None:
                            return candidate

    return None






# VIM declarations
# vim:tw=0:expandtab:autoindent:tabstop=4:shiftwidth=4:filetype=python:

  #############################################################################
  #
  # Copyright (c) 2003 Dell Computer Corporation
  # All Rights Reserved.
  #
  #############################################################################


from __future__ import generators

import types

def getText(nodelist):
    rc = ""
    if nodelist is not None:
        for node in nodelist:
            if node.nodeType == node.TEXT_NODE or node.nodeType == node.CDATA_SECTION_NODE:
                rc = rc + node.data
    return rc

def getNodeText( node, *args ):
    rc = ""
    node = getNodeElement(node, *args)
    if node is not None:
        rc = getText( node.childNodes )
    return rc

def getNodeAttribute(node, attrName, *args ):
    attribute = None
    aNode = getNodeElement(node, *args)
    if aNode is not None:
        attribute = aNode.getAttribute(attrName)
        if attribute == '':
            attribute = None
    return attribute

def setNodeAttributes(node, attrName, attrValue, *args ):
    aNode = getNodeElement(node, *args)
    if aNode is not None:
        aNode.setAttribute(attrName, attrValue)
    return 1


def iterNodeAttribute(node, attrName, *args):
    for aNode in iterNodeElement(node, *args):
        attribute = aNode.getAttribute(attrName)
        if attribute == '':
            attribute = None
        yield attribute
   

def iterNodeElement( node, *args ):
     if len(args) == 0:
        yield node
     elif node is not None:
        for search in node.childNodes:
            if isinstance(args[0], types.StringTypes):
                if search.nodeName == args[0]:
                    for elem in iterNodeElement( search, *args[1:] ):
                        yield elem
            else:
                if search.nodeName == args[0][0]:
                    attrHash = args[0][1]
                    found = 1
                    for (key, value) in attrHash.items():
                        if search.getAttribute( key ) != value:
                            found = 0
                    if found:
                        for elem in iterNodeElement( search, *args[1:] ):
                            yield elem


def getNodeElement( node, *args ):
    if len(args) == 0:
        return node

    #print "DEBUG: args(%s)" % repr(args)
    if node is not None:
        for search in node.childNodes:
            if isinstance(args[0], types.StringTypes):
                if search.nodeName == args[0]:
                    candidate = getNodeElement( search, *args[1:] )
                    if candidate is not None:
                        return candidate
            else:
                if search.nodeName == args[0][0]:
                    attrHash = args[0][1]
                    found = 1
                    for (key, value) in attrHash.items():
                        if search.getAttribute( key ) != value:
                            found = 0
                    if found:
                        candidate = getNodeElement( search, *args[1:] )
                        if candidate is not None:
                            return candidate

    return None






# the purpose of this file is so we can run from the build tree.
# for installation, this is replaced with a better version.
import os

__all__ = ["__VERSION__", "GETTEXT_PACKAGE",
    "localedir", "pkgdatadir", "pythondir", "pkgconfdir", "libdir",
    "LIBSMBIOS_C_SONAME"
    ]

LIBSMBIOS_C_SONAME =   "libsmbios_c.so.2"   # replaced at install time

import libsmbios_c
_modpath = os.path.realpath(libsmbios_c.__path__[0])

# the following vars are all substituted on install
__VERSION__="uninstalled-version"
GETTEXT_PACKAGE="libsmbios"
libdir    =os.path.join(_modpath, "..", "..", "..", "out", ".libs")
pythondir =os.path.join(_modpath, "..")
localedir =os.path.join(_modpath, "..", "..", "..", "po")
pkgdatadir=os.path.join(_modpath, "..", "..", "..", "doc")
pkgconfdir=os.path.join(_modpath, "..", "..", "..", "etc")

# end vars

